MemorySpeedExtended

Enum MemorySpeedExtended 

pub enum MemorySpeedExtended {
    MTs(u32),
    SeeSpeed,
}
Extended Speed of Memory

Variants



MTs(u32)

Speed of memory in megatransfers per second (MT/s)



SeeSpeed

See the speed field.

For compatibility with older SMBIOS parsers, memory devices slower than 65,535 MT/s should represent their speed using the Speed and Configured Memory Speed fields, leaving the Extended Speed and Extended Configured Memory Speed fields set to 0.