pub enum SystemBootStatus {
NoErrors,
NoBootableMedia,
NormalOSFailedToLoad,
FirmwareDetectedFailure,
OSDetectedFailure,
UserRequestedBoot,
SystemSecurityViolation,
PreviouslyRequestedImage,
SystemWatchdogTimerExpired,
None,
}Expand description
System Boot Status
Variants
NoErrors
No errors detected
NoBootableMedia
No bootable media
NormalOSFailedToLoad
“normal” operating system failed to load
FirmwareDetectedFailure
Firmware-detected hardware failure, including “unknown” failure types
OSDetectedFailure
Operating system-detected hardware failure For ACPI operating systems, the system firmware might set this reason code when the OS reports a boot failure through interfaces defined in the Simple Boot Flag Specification.
UserRequestedBoot
User-requested boot, usually through a keystroke
SystemSecurityViolation
System security violation
PreviouslyRequestedImage
Previously-requested image This reason code allows coordination between OS-present software and the OS-absent environment. For example, an OS-present application might enable (through a platform-specific interface) the system to boot to the PXE and request a specific boot-image.
SystemWatchdogTimerExpired
System watchdog timer expired, causing the system to reboot
None
A value unknown to this standard, check the raw value