CurrentProbeLocationAndStatus

Struct CurrentProbeLocationAndStatus 

pub struct CurrentProbeLocationAndStatus {
    pub raw: u8,
    pub status: CurrentProbeStatus,
    pub location: CurrentProbeLocation,
}
Electrical Current Probe Location and Status

Fields

raw: u8

Raw value

raw is most useful when value is None. This is most likely to occur when the standard was updated but this library code has not been updated to match the current standard.

status: CurrentProbeStatuslocation: CurrentProbeLocation