FirmwareInventoryCharacteristics

Struct FirmwareInventoryCharacteristics 

pub struct FirmwareInventoryCharacteristics {
    pub raw: u16,
}
Firmware Inventory Characteristics of SMBiosFirmwareInventoryInformation

Fields

raw: u16

Raw value

raw is useful when there are values not yet defiend. This is most likely to occur when the standard was updated but this library code has not been updated to match the current standard.

Implementations

Source

impl FirmwareInventoryCharacteristics

pub fn updatable(&self) -> bool

Updatable

This firmware can be updated by software.

pub fn write_protect(&self) -> bool

Write-Protect

This firmware is in a write-protected state.

Methods from Deref<Target = u16>

1.43.0 · Source

pub const MIN: u16 = 0

1.43.0 · Source

pub const MAX: u16

1.53.0 · Source

pub const BITS: u32