pub struct RackTypeData {
pub raw: u8,
pub value: RackType,
}Expand description
Rack Type Data
Fields
raw: u8Raw value
raw is most useful when value is None. This is most likely to occur when the standard was updated but this library code has not been updated to match the current standard.
value: RackTypeThe contained RackType value