pub struct CurrentProbeLocationAndStatus {
pub raw: u8,
pub status: CurrentProbeStatus,
pub location: CurrentProbeLocation,
}Expand description
Electrical Current Probe Location and Status
Fields
raw: u8Raw value
raw is most useful when value is None. This is most likely to occur when the standard was updated but this library code has not been updated to match the current standard.
status: CurrentProbeStatuslocation: CurrentProbeLocationTrait Implementations
impl Eq for CurrentProbeLocationAndStatus
Sourceimpl From<u8> for CurrentProbeLocationAndStatus
impl From<u8> for CurrentProbeLocationAndStatus
impl StructuralPartialEq for CurrentProbeLocationAndStatus